@@ -35,7 +35,7 @@ fcros <- function(xdata, cont, test, log2.opt=0, trim.opt=0.25) {
     rmat.val <- rmatCalc(fvect, n, m1, m2);
     rmat <- matrix(rmat.val$rvectC, ncol = m1m2);
     FC <- rmat.val$FCC;
-    rvectFC <- rmat.val$rvectC;
+    rvectC <- rmat.val$rvectC;
 
     # compute the standard ranks matrix
     rmat.s <- apply(rmat, 2, rank, ties.method = "average")/n;
@@ -53,10 +53,10 @@ fcros <- function(xdata, cont, test, log2.opt=0, trim.opt=0.25) {
        rmat.val <- moyStdCalc(rvect, n, m2);
        moyV <- rmat.val$moyC;
        stdV <- rmat.val$stdC;
-       FC2 <- fc2Calc(rvectFC, n, m1m2, idx, m2)
+       FC2 <- fc2Calc(rvectC, n, m1m2, idx, m2)
        rm(rvect);
        rm(rmat.val);
-       rm(rvectFC);
+       rm(rvectC);
     }
     else {
          rmat.sr <- rmat.s;
@@ -66,10 +66,10 @@ fcros <- function(xdata, cont, test, log2.opt=0, trim.opt=0.25) {
          rmat.val <- moyStdCalc(rvect, n, m2);
          moyV <- rmat.val$moyC;
          stdV <- rmat.val$stdC;
-         FC2 <- fc2Calc(rvectFC, n, m1m2, idx, m2)
+         FC2 <- fc2Calc(rvectC, n, m1m2, idx, m2)
          rm(rvect);
          rm(rmat.val);
-         rm(rvectFC);
+         rm(rvectC);
     }
 
     # compute averages ranks
